Package 'realtalk'

Title: Price index data for the US economy
Description: Makes it easy to use US price index data like the CPI.
Authors: Ben Zipperer [aut, cre], Economic Policy Institute [cph, fnd]
Maintainer: Ben Zipperer <[email protected]>
License: MIT + file LICENSE
Version: 2026.5.13
Built: 2026-05-14 04:54:53 UTC
Source: https://github.com/economic/realtalk

Help Index


Price indexes available in the realtalk package

Description

Price indexes available in the realtalk package

Usage

available_price_indexes

Format

The data frame available_price_indexes shows which datasets are available from the ⁠realtalk package⁠. It has six columns:

data_source

Short price index name

frequency

time frequency of data available)

seasonal

seasonally adjustment status of the data

min_date

first date of availability

max_date

last date of availability

package_data_name

internal data name of the series

Use the package_data_name value to load a specific series.

Examples

available_price_indexes

Chained Consumer Price Index for Urban Consumers (C-CPI-U) data

Description

Monthly, quarterly, or annual C-CPI-U price indexes

Usage

c_cpi_u_monthly_nsa

c_cpi_u_quarterly_nsa

c_cpi_u_annual

Format

The data frame c_cpi_u_monthly_nsa contains not-seasonally adjusted monthly price index levels of the Chained CPI-U (C-CPI-U). It has three columns:

year

numeric year

month

numeric calendar month (1-12)

c_cpi_u

value of the C-CPI-U price index

The data frame c_cpi_u_quarterly_nsa contains not-seasonally adjusted quarterly price index levels of the Chained CPI-U (C-CPI-U). It has three columns:

year

numeric year

quarter

numeric calendar quarter (1-4)

c_cpi_u

value of the C-CPI-U price index

The data frame c_cpi_u_annual contains the annual price index level of the Chained CPI-U (C-CPI-U). It has two columns:

year

numeric year

c_cpi_u

value of the C-CPI-U price index

The monthly series cpi_u_monthly_nsa is taken from https://www.bls.gov/cpi/. The quarterly series cpi_u_quarterly_nsa series is the quarterly mean.

See Also

cpi_u_rs_monthly_nsa and cpi_u_rs_annual for the CPI-U-RS, a CPI index that is consistently defined over time and goes back to 1978.

Examples

c_cpi_u_monthly_nsa

Extended Chained Consumer Price Index for Urban Consumers (C-CPI-U)

Description

The monthly, quarterly, or annual C-CPI-U series extended to 1937 through the present, based on CPI-U-RS, CPI-U, and CPI-U-X1.

Usage

c_cpi_u_extended_monthly_nsa

c_cpi_u_extended_monthly_sa

c_cpi_u_extended_quarterly_nsa

c_cpi_u_extended_quarterly_sa

c_cpi_u_extended_annual

Format

The extended C-CPI-U series uses the C-CPI-U since 2000 and extends it retroactively by merging it to the CPI-U-RS (1978-1999), CPI-U-X1 (1967-1977), and CPI-U (1966 and before).

The data frames c_cpi_u_extended_monthly_nsa and c_cpi_u_extended_monthly_sa contain, respectively, the not-seasonally and seasonally adjusted price index levels of the extended C-CPI-U. They have three columns:

year

numeric year

month

numeric calendar month (1-12)

c_cpi_u_extended

value of the C-CPI-U extended price index

The data frames c_cpi_u_extended_quarterly_nsa and c_cpi_u_extended_quarterly_sa are the quarterly versions of these series. They have three columns:

year

numeric year

quarter

numeric calendar quarter (1-4)

c_cpi_u_extended

value of the C-CPI-U extended price index

The data frame ⁠c_cpi_u_extended annual⁠ contains the annual price index level of the extended C-CPI-U. It has two columns:

year

numeric year

c_cpi_u_extended

value of the C-CPI-U extended price index

The seasonal adjustment in c_cpi_u_extended_monthly_sa is simply a multiplication of the non-seasonally adjusted c_cpi_u_extended_monthly_nsa values by the ratio of the cpi_u_monthly_sa to cpi_u_monthly_nsa. The quarterly c_cpi_u_extended_quarterly_nsa and c_cpi_u_extended_quarterly_sa series are the quarterly means of their respective monthly series.

For months where CPI data was not published (e.g., October 2025), the monthly extended series values are linearly interpolated from the adjacent months' values. The quarterly series are then computed as usual from the monthly values including any interpolated months.

For annual statistics, the U.S. Census Bureau currently uses a similar combination of price indexes to extend the C-CPI-U: https://www.census.gov/topics/income-poverty/income/guidance/current-vs-constant-dollars.html.

Examples

c_cpi_u_extended_annual

Consumer Price Index for Urban Consumers (CPI-U) data

Description

Monthly, quarterly, or annual CPI-U price indexes

Usage

cpi_u_monthly_nsa

cpi_u_monthly_sa

cpi_u_quarterly_nsa

cpi_u_quarterly_sa

cpi_u_annual

Format

The data frames cpi_u_monthly_sa and cpi_u_monthly_nsa contain, respectively, seasonally adjusted or not seasonally adjusted monthly price index levels of the CPI-U. They have three columns:

year

numeric year

month

numeric calendar month (1-12)

cpi_u

value of the CPI-U price index

#' @format The data frames cpi_u_quarterly_sa and cpi_u_quarterly_nsa contain, respectively, seasonally adjusted or not seasonally adjusted quarterly price index levels of the CPI-U. They have three columns:

year

numeric year

quarter

numeric calendar quarter (1-4)

cpi_u

value of the CPI-U price index

The data frame cpi_u_annual contains the annual price index level of the CPI-U. It has two columns:

year

numeric year

cpi_u

value of the CPI-U price index

https://www.bls.gov/cpi/

See Also

cpi_u_rs_monthly_nsa and cpi_u_rs_annual for the CPI-U-RS, an index that is more consistent over time than the CPI-U and incorporates more recent improvements to the CPI-U into the entire time series. The quarterly cpi_u_quarterly_nsa and cpi_u_quarterly_sa series are the quarterly means of their respective monthly series.

Examples

cpi_u_monthly_nsa

Consumer Price Index for Urban Consumers Research Series (CPI-U-RS) data

Description

Monthly or annual CPI-U-RS price indexes

Usage

cpi_u_rs_monthly_nsa

cpi_u_rs_annual

Format

The data frame cpi_u_rs_monthly_nsa contains the not seasonally adjusted monthly price index levels of the CPI-U-RS (CPI-U research series). The CPI-U-RS is more consistent over time than the CPI-U and incorporates more recent improvements to the CPI-U into the entire time series. It has three columns:

year

numeric year

month

numeric calendar month (1-12)

cpi_u_rs

value of the CPI-U-RS price index

The data frame cpi_u_rs_annual contains the annual price index level of the CPI-U-RS. It has two columns:

year

numeric year

cpi_u_rs

value of the CPI-U-RS price index

https://www.bls.gov/cpi/research-series/r-cpi-u-rs-home.htm

See Also

c_cpi_u_extended_annual extends the CPI-U-RS from 1937 to the present using the c_cpi_u and other series.

Examples

cpi_u_rs_annual

Experimental Consumer Price Index for Urban Consumers X1 (CPI-U-X1) data

Description

Monthly or annual CPI-U-X1 price indexes

Usage

cpi_u_x1_monthly_nsa

cpi_u_x1_annual

Format

The data frame cpi_u_x1_monthly_nsa contains the not seasonally adjusted monthly price index levels of the CPI-U-X1 from January 1967 through December 1982. It has three columns:

year

numeric year

month

numeric calendar month (1-12)

cpi_u_x1

value of the CPI-U-X1 price index

The data frame cpi_u_x1_annual contains the annual average price index level of the CPI-U-X1. It has two columns:

year

numeric year

cpi_u_x1

value of the CPI-U-X1 price index

Emailed spreadsheet from the US Bureau of Labor Statistics

See Also

c_cpi_u_extended_annual extends the CPI-U-X1 from 1937 to the present using the c_cpi_u and other series.

Examples

cpi_u_x1_annual

Get price index series as a data frame

Description

Get price index series as a data frame

Usage

get_price_index(index_name, frequency, seasonal = NA)

Arguments

index_name

Name of the price index, as specified by index name in available_price_indexes

frequency

"monthly" or "annual"

seasonal

"NSA" or "SA" for monthly data; NA (default) for annual

Value

A tibble with the requested price index

Examples

get_price_index("CPI-U-RS", "monthly", "NSA")

Personal Consumption Expenditures (PCE) price index

Description

Monthly, quarterly, or annual PCE price indexes

Usage

pce_monthly_sa

pce_quarterly_sa

pce_annual

Format

The data frame pce_monthly_sa contains seasonally adjusted monthly price index levels of the PCE. It has three columns:

year

numeric year

month

numeric calendar month (1-12)

pce

value of the PCE price index

The data frame pce_quarterly_sa contains seasonally adjusted quarterly price index levels of the PCE. It has three columns:

year

numeric year

quarter

numeric calendar quarter (1-3)

pce

value of the PCE price index

The data frame pce_annual contains the annual price index level of the PCE. It has two columns:

year

numeric year

pce

value of the PCE price index

https://www.bea.gov/data/personal-consumption-expenditures-price-index

Examples

pce_annual

Example nominal US federal minimum wage data

Description

Example nominal US federal minimum wage data

Usage

us_minimum_wage_monthly

us_minimum_wage_annual

Format

The data frame us_minimum_wage_annual contains the nominal value of the annual US federal minimum wage since 1938. It has two columns:

year

numeric year

minimum_wage

maximum value of the US federal minimum wage that year

The data frame us_minimum_wage_monthly contains the nominal value of the monthly US federal minimum wage since 1938. It has three columns:

year

numeric year

year

numeric month

minimum_wage

maximum value of the US federal minimum wage that month

US Department of Labor

Examples

us_minimum_wage_monthly