| Title: | Price index data for the US economy |
|---|---|
| Description: | Makes it easy to use US price index data like the CPI. |
| Authors: | Ben Zipperer [aut, cre], Economic Policy Institute [cph, fnd] |
| Maintainer: | Ben Zipperer <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2026.5.13 |
| Built: | 2026-05-14 04:54:53 UTC |
| Source: | https://github.com/economic/realtalk |
realtalk packagePrice indexes available in the realtalk package
available_price_indexesavailable_price_indexes
The data frame available_price_indexes shows which datasets are
available from the realtalk package. It has six columns:
Short price index name
time frequency of data available)
seasonally adjustment status of the data
first date of availability
last date of availability
internal data name of the series
Use the package_data_name value to load a specific series.
available_price_indexesavailable_price_indexes
Monthly, quarterly, or annual C-CPI-U price indexes
c_cpi_u_monthly_nsa c_cpi_u_quarterly_nsa c_cpi_u_annualc_cpi_u_monthly_nsa c_cpi_u_quarterly_nsa c_cpi_u_annual
The data frame c_cpi_u_monthly_nsa
contains not-seasonally adjusted monthly price index levels of the
Chained CPI-U (C-CPI-U). It has three columns:
numeric year
numeric calendar month (1-12)
value of the C-CPI-U price index
The data frame c_cpi_u_quarterly_nsa
contains not-seasonally adjusted quarterly price index levels of the
Chained CPI-U (C-CPI-U). It has three columns:
numeric year
numeric calendar quarter (1-4)
value of the C-CPI-U price index
The data frame c_cpi_u_annual contains the annual
price index level of the Chained CPI-U (C-CPI-U). It has two columns:
numeric year
value of the C-CPI-U price index
The monthly series cpi_u_monthly_nsa is taken from
https://www.bls.gov/cpi/.
The quarterly series cpi_u_quarterly_nsa series is the quarterly mean.
cpi_u_rs_monthly_nsa and cpi_u_rs_annual
for the CPI-U-RS, a CPI index that is consistently defined over time and goes
back to 1978.
c_cpi_u_monthly_nsac_cpi_u_monthly_nsa
The monthly, quarterly, or annual C-CPI-U series extended to 1937 through the present, based on CPI-U-RS, CPI-U, and CPI-U-X1.
c_cpi_u_extended_monthly_nsa c_cpi_u_extended_monthly_sa c_cpi_u_extended_quarterly_nsa c_cpi_u_extended_quarterly_sa c_cpi_u_extended_annualc_cpi_u_extended_monthly_nsa c_cpi_u_extended_monthly_sa c_cpi_u_extended_quarterly_nsa c_cpi_u_extended_quarterly_sa c_cpi_u_extended_annual
The extended C-CPI-U series uses the C-CPI-U since 2000 and extends it retroactively by merging it to the CPI-U-RS (1978-1999), CPI-U-X1 (1967-1977), and CPI-U (1966 and before).
The data frames c_cpi_u_extended_monthly_nsa and
c_cpi_u_extended_monthly_sa contain, respectively, the
not-seasonally and seasonally adjusted price index levels of the
extended C-CPI-U. They have three columns:
numeric year
numeric calendar month (1-12)
value of the C-CPI-U extended price index
The data frames c_cpi_u_extended_quarterly_nsa and
c_cpi_u_extended_quarterly_sa are the quarterly versions of these
series. They have three columns:
numeric year
numeric calendar quarter (1-4)
value of the C-CPI-U extended price index
The data frame c_cpi_u_extended annual contains the annual
price index level of the extended C-CPI-U. It has two columns:
numeric year
value of the C-CPI-U extended price index
The seasonal adjustment in c_cpi_u_extended_monthly_sa is simply
a multiplication of the non-seasonally adjusted
c_cpi_u_extended_monthly_nsa values by the ratio of the
cpi_u_monthly_sa to cpi_u_monthly_nsa.
The quarterly c_cpi_u_extended_quarterly_nsa and c_cpi_u_extended_quarterly_sa
series are the quarterly means of their respective monthly series.
For months where CPI data was not published (e.g., October 2025), the monthly extended series values are linearly interpolated from the adjacent months' values. The quarterly series are then computed as usual from the monthly values including any interpolated months.
For annual statistics, the U.S. Census Bureau currently uses a similar combination of price indexes to extend the C-CPI-U: https://www.census.gov/topics/income-poverty/income/guidance/current-vs-constant-dollars.html.
c_cpi_u_extended_annualc_cpi_u_extended_annual
Monthly, quarterly, or annual CPI-U price indexes
cpi_u_monthly_nsa cpi_u_monthly_sa cpi_u_quarterly_nsa cpi_u_quarterly_sa cpi_u_annualcpi_u_monthly_nsa cpi_u_monthly_sa cpi_u_quarterly_nsa cpi_u_quarterly_sa cpi_u_annual
The data frames cpi_u_monthly_sa and cpi_u_monthly_nsa
contain, respectively, seasonally adjusted or not seasonally adjusted monthly
price index levels of the CPI-U. They have three columns:
numeric year
numeric calendar month (1-12)
value of the CPI-U price index
#' @format The data frames cpi_u_quarterly_sa and cpi_u_quarterly_nsa
contain, respectively, seasonally adjusted or not seasonally adjusted quarterly
price index levels of the CPI-U. They have three columns:
numeric year
numeric calendar quarter (1-4)
value of the CPI-U price index
The data frame cpi_u_annual contains the annual
price index level of the CPI-U. It has two columns:
numeric year
value of the CPI-U price index
cpi_u_rs_monthly_nsa and cpi_u_rs_annual
for the CPI-U-RS, an index that is more consistent over time than the CPI-U
and incorporates more recent improvements to the CPI-U into the
entire time series. The quarterly cpi_u_quarterly_nsa and
cpi_u_quarterly_sa series are the quarterly means of their
respective monthly series.
cpi_u_monthly_nsacpi_u_monthly_nsa
Monthly or annual CPI-U-RS price indexes
cpi_u_rs_monthly_nsa cpi_u_rs_annualcpi_u_rs_monthly_nsa cpi_u_rs_annual
The data frame cpi_u_rs_monthly_nsa contains the
not seasonally adjusted monthly price index levels of the CPI-U-RS
(CPI-U research series). The CPI-U-RS is more consistent over time than
the CPI-U and incorporates more recent improvements to the CPI-U into the
entire time series. It has three columns:
numeric year
numeric calendar month (1-12)
value of the CPI-U-RS price index
The data frame cpi_u_rs_annual contains the annual
price index level of the CPI-U-RS. It has two columns:
numeric year
value of the CPI-U-RS price index
https://www.bls.gov/cpi/research-series/r-cpi-u-rs-home.htm
c_cpi_u_extended_annual extends the
CPI-U-RS from 1937 to the present using the c_cpi_u and other series.
cpi_u_rs_annualcpi_u_rs_annual
Monthly or annual CPI-U-X1 price indexes
cpi_u_x1_monthly_nsa cpi_u_x1_annualcpi_u_x1_monthly_nsa cpi_u_x1_annual
The data frame cpi_u_x1_monthly_nsa contains the
not seasonally adjusted monthly price index levels of the CPI-U-X1
from January 1967 through December 1982. It has three columns:
numeric year
numeric calendar month (1-12)
value of the CPI-U-X1 price index
The data frame cpi_u_x1_annual contains the annual average
price index level of the CPI-U-X1. It has two columns:
numeric year
value of the CPI-U-X1 price index
Emailed spreadsheet from the US Bureau of Labor Statistics
c_cpi_u_extended_annual extends the
CPI-U-X1 from 1937 to the present using the c_cpi_u and other series.
cpi_u_x1_annualcpi_u_x1_annual
Get price index series as a data frame
get_price_index(index_name, frequency, seasonal = NA)get_price_index(index_name, frequency, seasonal = NA)
index_name |
Name of the price index, as specified by index name in |
frequency |
"monthly" or "annual" |
seasonal |
"NSA" or "SA" for monthly data; NA (default) for annual |
A tibble with the requested price index
get_price_index("CPI-U-RS", "monthly", "NSA")get_price_index("CPI-U-RS", "monthly", "NSA")
Monthly, quarterly, or annual PCE price indexes
pce_monthly_sa pce_quarterly_sa pce_annualpce_monthly_sa pce_quarterly_sa pce_annual
The data frame pce_monthly_sa contains seasonally adjusted monthly
price index levels of the PCE. It has three columns:
numeric year
numeric calendar month (1-12)
value of the PCE price index
The data frame pce_quarterly_sa contains seasonally adjusted
quarterly price index levels of the PCE. It has three columns:
numeric year
numeric calendar quarter (1-3)
value of the PCE price index
The data frame pce_annual contains the annual
price index level of the PCE. It has two columns:
numeric year
value of the PCE price index
https://www.bea.gov/data/personal-consumption-expenditures-price-index
pce_annualpce_annual
Example nominal US federal minimum wage data
us_minimum_wage_monthly us_minimum_wage_annualus_minimum_wage_monthly us_minimum_wage_annual
The data frame us_minimum_wage_annual contains the
nominal value of the annual US federal minimum wage since 1938.
It has two columns:
numeric year
maximum value of the US federal minimum wage that year
The data frame us_minimum_wage_monthly contains the
nominal value of the monthly US federal minimum wage since 1938.
It has three columns:
numeric year
numeric month
maximum value of the US federal minimum wage that month
us_minimum_wage_monthlyus_minimum_wage_monthly